from django.apps import AppConfig


class DjaqUiConfig(AppConfig):
    name = "djaq.djaq_ui"
    label = "djaq_ui"
